@@ -1,6 +1,20 @@
 from .http import HTTPClient, Route
-from .errors import CordedError, HTTPError, BadRequest, Unauthorized, Forbidden, NotFound, PayloadTooLarge, TooManyRequests, DiscordServerError
+from .ws import GatewayClient, Shard
+from .errors import (
+    CordedError,
+    HTTPError,
+    BadRequest,
+    Unauthorized,
+    Forbidden,
+    NotFound,
+    PayloadTooLarge,
+    TooManyRequests,
+    DiscordServerError,
+)
 from .constants import VERSION as __version__
+from .objects import Object
+from .client import CordedClient
+from .helpers import BitField
 
 __all__ = (
     HTTPClient,
@@ -14,5 +28,10 @@ __all__ = (
     PayloadTooLarge,
     TooManyRequests,
     DiscordServerError,
+    Object,
+    GatewayClient,
+    Shard,
+    CordedClient,
+    BitField,
     __version__,
 )
